@@ -108,7 +108,7 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 			to_code = xstrdup (arg);
 			if (!strstr (to_code, "//"))
 				to_code = appendstr (to_code, "//TRANSLIT",
-						     NULL);
+						     (void *) 0);
 			return 0;
 		case 'd':
 			debug_level = 1;
