@@ -355,10 +355,10 @@ static void use_grep (const char * const *pages, int num_pages, char *manpath,
 								     GREP));
 			pipecmd_argstr (grep_cmd, flags);
 			pipecmd_args (grep_cmd, anchored_page, whatis_file,
-				      NULL);
+				      (void *) 0);
 			pipecmd_pre_exec (grep_cmd, sandbox_load, sandbox_free,
 					  sandbox);
-			grep_pl = pipeline_new_commands (grep_cmd, NULL);
+			grep_pl = pipeline_new_commands (grep_cmd, (void *) 0);
 
 			if (pipeline_run (grep_pl) == 0)
 				found[i] = 1;
@@ -461,9 +461,10 @@ static void display (MYDBM_FILE dbf, struct mandata *info, const char *page)
 		string = xasprintf ("%.*s...", line_len / 2 - 3, page_name);
 	else
 		string = xstrdup (page_name);
-	string = appendstr (string, " (", newinfo->ext, ")", NULL);
+	string = appendstr (string, " (", newinfo->ext, ")", (void *) 0);
 	if (!STREQ (newinfo->pointer, "-") && !STREQ (newinfo->pointer, page))
-		string = appendstr (string, " [", newinfo->pointer, "]", NULL);
+		string = appendstr (string, " [", newinfo->pointer, "]",
+				    (void *) 0);
 
 	if (strlen (string) < (size_t) 20) {
 		int i;
@@ -472,14 +473,14 @@ static void display (MYDBM_FILE dbf, struct mandata *info, const char *page)
 			string[i] = ' ';
 		string[i] = '\0';
 	}
-	string = appendstr (string, " - ", NULL);
+	string = appendstr (string, " - ", (void *) 0);
 
 	rest = line_len - strlen (string);
 	if (!long_output && strlen (whatis) > (size_t) rest) {
 		whatis[rest - 3] = '\0';
-		string = appendstr (string, whatis, "...\n", NULL);
+		string = appendstr (string, whatis, "...\n", (void *) 0);
 	} else
-		string = appendstr (string, whatis, "\n", NULL);
+		string = appendstr (string, whatis, "\n", (void *) 0);
 
 	string_conv = simple_convert (conv_to_locale, string);
 	fputs (string_conv, stdout);
@@ -829,6 +830,8 @@ nextpage:
 		free_mandata_elements (&info);
 	}
 
+	free (found_here);
+
 	for (i = 0; i < num_pages; ++i)
 		free (lowpages[i]);
 	free (lowpages);
