@@ -30,7 +30,7 @@
 #include <stdlib.h>
 
 #include "argp.h"
-#include "dirname.h"
+#include "progname.h"
 #include "xvasprintf.h"
 
 #include "gettext.h"
@@ -49,7 +49,6 @@
 #include "manp.h"
 #include "zsoelim.h"
 
-char *program_name;
 int quiet = 1;
 man_sandbox *sandbox;
 
@@ -106,7 +105,7 @@ int main (int argc, char *argv[])
 	char *manp;
 	int i;
 
-	program_name = base_name (argv[0]);
+	set_program_name (argv[0]);
 
 	init_debug ();
 	pipeline_install_post_fork (pop_all_cleanups);
